import abc
import glob
import os
import unittest

from integration.partial.integration_test_utils import IntegrationTestUtils


class BaseSurveyTestSuite:

    class SurveyTestSuite(unittest.TestCase):

        """
        the name passed to the Processor.py to define the component
        """
        SURVEY_COMPONENT_NAME = "Survey"
        """
        the prefix of the directory created by thr Processor.py, e.g. SURVEY_2020-01-01
        """
        SURVEY_PROCESSOR_DIR = "SURVEYDATA"

        @abc.abstractmethod
        def set_expected_values(self):
            pass


        def test_standard_run_input_status_success(self):
            status_file_path = os.path.join(IntegrationTestUtils.TEST_OUT_PATH,
                                            IntegrationTestUtils.TEST_JOB_DIR, "STATUS_SUCCESS*")
            success_file_exists: bool = len(glob.glob(status_file_path)) > 0
            self.assertTrue(success_file_exists)


        def test_standard_run_input_merged_survey_created(self):
            status_file_path = os.path.join(IntegrationTestUtils.TEST_OUT_PATH,
                                            IntegrationTestUtils.TEST_JOB_DIR,
                                            "ExportCSV", "Merged_SurveyData.csv")
            success_file_exists: bool = os.path.isfile(status_file_path)
            file_not_empty: bool = IntegrationTestUtils.check_file_not_empty(status_file_path)
            self.assertTrue(success_file_exists)
            self.assertTrue(file_not_empty)